import { EnumerationParameterType, ParameterLocation, ParameterType, HeaderParameter, QueryParameter, PathParameter, LegacyParameter } from './types';
import { z } from 'zod';
export declare function convertParams(field: any, params: any): z.ZodType;
export declare class Arr {
    static generator: boolean;
    constructor(innerType: any, params?: ParameterType);
}
export declare class Obj {
    static generator: boolean;
    constructor(fields: object, params?: ParameterType);
}
export declare const Num: LegacyParameter<z.ZodNumber>;
export declare const Int: LegacyParameter<z.ZodNumber>;
export declare const Str: LegacyParameter<z.ZodString>;
export declare const DateTime: LegacyParameter<z.ZodString>;
export declare const Regex: LegacyParameter<z.ZodString>;
export declare const Email: LegacyParameter<z.ZodString>;
export declare const Uuid: LegacyParameter<z.ZodString>;
export declare const Hostname: LegacyParameter<z.ZodString>;
export declare const Ipv4: LegacyParameter<z.ZodString>;
export declare const Ipv6: LegacyParameter<z.ZodString>;
export declare const DateOnly: LegacyParameter<z.ZodString>;
export declare const Bool: LegacyParameter<z.ZodBoolean>;
export declare class Enumeration {
    static generator: boolean;
    constructor(params: EnumerationParameterType);
}
export declare function Query<Z extends z.ZodType>(type: Z): QueryParameter<Z>;
export declare function Query<Z extends z.ZodType>(type: Z, params: ParameterLocation & {
    required: false;
}): QueryParameter<z.ZodOptional<Z>>;
export declare function Query<Z extends z.ZodType>(type: Z, params: ParameterLocation): QueryParameter<Z>;
export declare function Query<Z extends z.ZodType>(type: [Z]): QueryParameter<z.ZodArray<Z>>;
export declare function Query<Z extends z.ZodType>(type: [Z], params: ParameterLocation & {
    required: false;
}): QueryParameter<z.ZodOptional<z.ZodArray<Z>>>;
export declare function Query<Z extends z.ZodType>(type: [Z], params: ParameterLocation): QueryParameter<z.ZodArray<Z>>;
export declare function Query(type: any): QueryParameter;
export declare function Query(type: any, params: ParameterLocation): QueryParameter;
export declare function Path<Z extends z.ZodType>(type: Z): PathParameter<Z>;
export declare function Path<Z extends z.ZodType>(type: Z, params: ParameterLocation & {
    required: false;
}): PathParameter<z.ZodOptional<Z>>;
export declare function Path<Z extends z.ZodType>(type: Z, params: ParameterLocation): PathParameter<Z>;
export declare function Path<Z extends z.ZodType>(type: [Z]): PathParameter<z.ZodArray<Z>>;
export declare function Path<Z extends z.ZodType>(type: [Z], params: ParameterLocation & {
    required: false;
}): PathParameter<z.ZodOptional<z.ZodArray<Z>>>;
export declare function Path<Z extends z.ZodType>(type: [Z], params: ParameterLocation): PathParameter<z.ZodArray<Z>>;
export declare function Path(type: any): PathParameter;
export declare function Path(type: any, params: ParameterLocation): PathParameter;
export declare function Header<Z extends z.ZodType>(type: Z): HeaderParameter<Z>;
export declare function Header<Z extends z.ZodType>(type: Z, params: ParameterLocation & {
    required: false;
}): HeaderParameter<z.ZodOptional<Z>>;
export declare function Header<Z extends z.ZodType>(type: Z, params: ParameterLocation): HeaderParameter<Z>;
export declare function Header<Z extends z.ZodType>(type: [Z]): HeaderParameter<z.ZodArray<Z>>;
export declare function Header<Z extends z.ZodType>(type: [Z], params: ParameterLocation & {
    required: false;
}): HeaderParameter<z.ZodOptional<z.ZodArray<Z>>>;
export declare function Header<Z extends z.ZodType>(type: [Z], params: ParameterLocation): HeaderParameter<z.ZodArray<Z>>;
export declare function Header(type: any): HeaderParameter;
export declare function Header(type: any, params: ParameterLocation): HeaderParameter;
export declare function extractParameter(request: Request, query: Record<string, any>, name: string, location: string): any;
export declare function extractQueryParameters(request: Request, schema?: z.ZodObject<any>): Record<string, any> | null;
